about summary refs log tree commit diff stats
path: root/post.sh
diff options
context:
space:
mode:
Diffstat (limited to 'post.sh')
-rwxr-xr-xpost.sh16
1 files changed, 15 insertions, 1 deletions
diff --git a/post.sh b/post.sh
index 1d048f9..ccd097b 100755
--- a/post.sh
+++ b/post.sh
@@ -1,5 +1,19 @@
 #!/bin/sh
+set -e
 
-# Execute commands after building. Like pushing to an FTP server. #
+# Execute commands after building. Like pushing to an FTP server.              #
+# Below is an example of what commands you could use.                          #
+
+bsdtar -a -cvf program-$CURRENT_COMMIT.tar.gz app/
+ftp -in <<EOF
+open 192.168.1.1
+user example password
+mkdir $CURRENT_COMMIT
+cd $CURRENT_COMMIT
+put program-$CURRENT_COMMIT.tar.gz program-$CURRENT_COMMIT.tar.gz
+put $WORKING_DIRECTORY/output.log output.log
+close
+bye
+EOF
 
 exit 0